package com.jz.common.constant;

import com.alibaba.fastjson.JSONObject;
import com.jz.common.utils.web.HttpClientUtils;
import com.jz.dmp.modules.service.impl.DmpApiServiceMangeServiceImpl;
import org.apache.commons.lang3.StringUtils;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

import java.util.Map;

/**
 * @ClassName: GatewayApiConstant
 * @Description: 服务网关api地址
 * @Author Bellamy
 * @Date 2021/2/4
 * @Version 1.0
 */
public class GatewayApiConstant {

    //列表分页查询url
    public static final String orgListPage = "/api/organization/listOrg";
    //删除组织url
    public static final String delOrg = "/api/organization/logoutOrg";
    //新增组织url
    public static final String addOrg = "/api/organization/add";
    //编辑组织url
    public static final String updateOrg = "/api/organization/update";
    //根据组织id获取组织详情url
    public static final String orgDetail = "/api/organization/getOrgDetail";
    //授权给他人的API-列表分页查询url
    public static final String apiAuthListPage = "/api/auth/auth-list";
    //取消授权url
    public static final String cancelApiAuth = "/api/auth/update-auth-info";
    //发布的API-API列表分页查询url
    public static final String apiListPage = "/api/interface/listApiInterface";
    //删除APIurl
    public static final String delApi = "/api/interface/delDMPApiInterface";
    //根据apiid获取API详情url
    public static final String getApiInfo = "/api/interface/getApiDetail";
    //授权给组织url
    public static final String apiAuthToOrg = "/api/auth/dmp-auth-api";
    //测试url
    public static final String testApi = "/api/request/gateway";
    //查看日志url
    public static final String checkApiLog = "/api/logging/listApiLog";
    //授权模糊查询组织信息url
    public static final String authOrgList = "/api/auth/getAuthNameList";
    //保存API(第三方)基本信息url
    public static final String addApiInfo = "/api/producer/addCustomApi";
    //保存API(大数据查询/标签查询)url
    public static final String addApiBigData = "/api/producer/addDataTableSelect";
    //编辑API(第三方)基本信息url
    public static final String updateApiInfo = "/api/producer/saveUpdate";
    //API计量调用次数和执行时长url
    public static final String countAPiCallStat = "/api/interface/countAPiCallStat";
    //API计量--API未调用列表url
    public static final String notCalledList = "/api/interface/listUnCallApi";
    //API计量--API已调用列表url
    public static final String listCallApi = "/api/interface/listCallApi";
    //服务发布/服务取消url
    public static final String apiPublishCancel = "/api/producer/optionApiIssueStatus";
    //盐值重置url
    public static final String saltReset = "/api/auth/reset-salt";
    //授权管理-api列表url
    public static final String authApiList = "/api/auth/getServiceAuthList";
    //授权
    public static final String authUserApi = "/api/auth/user-auth-api";
    //上传（发送给数据银行）
    public static final String serverUpload = "/api/producer/serverUpload";
    //日志详情
    public static final String logDetails = "/api/logging/getReqDetail";
    //服务开发 api列表
    public static final String listServerApplyApi = "/api/interface/listServerApplyApi";
    //获取文件夹树
    public static final String folderTree = "/api/producer/getFileCatalog";
    //服务开发---获取ApiId
    public static final String getApiId = "/api/producer/getCustomApiId";
    //创建项目文件夹
    public static final String createProjectFolder = "/api/producer/createProjectFolder";
    //授权--组织名称查询
    public static final String getOrgNameList = "/api/auth/get-org-list";
    //API测试--下拉框
    public static final String listGetApiKey = "/api/interface/listGetApiKey";
    //删除文件夹
    public static final String delFolder = "/api/producer/delProjectFolder";
    //删除文件夹
    public static final String functionTemplate = "/api/producer/getFunctionTemplateList";

    private static Logger logger = LoggerFactory.getLogger(GatewayApiConstant.class);

    /*
     * post 请求获取数据
     * */
    public static JsonResult postRequest2GetData(String url, String param) throws Exception {
        JsonResult result = new JsonResult();
        String resultData = HttpClientUtils.post(url, param);
        if (StringUtils.isEmpty(resultData)) {
            throw new RuntimeException("failed！");
        }
        logger.info("############## response results{}" + resultData);

        Map jsonObject = JSONObject.parseObject(resultData);
        if (jsonObject.containsKey("code")) {
            if ("200".equals(jsonObject.get("code").toString())) {
                if (jsonObject.containsKey("data"))
                    return JsonResult.ok(jsonObject.get("data"));
                else
                    return JsonResult.ok();
            }
        }
        if (jsonObject.containsKey("msg")) {
            logger.info(jsonObject.get("msg").toString());
            result.setMessage(jsonObject.get("msg").toString());
            result.setCode(ResultCode.INTERNAL_SERVER_ERROR);
        }
        return result;
    }

    /*
     * get 请求获取数据
     * */
    public static JsonResult getRequest2GetData(String url, Map params) throws Exception {
        JsonResult result = new JsonResult();
        String returnData = HttpClientUtils.getJsonForParam(url, params);
        if (StringUtils.isEmpty(returnData)) {
            throw new RuntimeException("failed！");
        }
        logger.info("############## response results{}" + returnData);
        Map jsonObject = JSONObject.parseObject(returnData);
        if (jsonObject.containsKey("code")) {
            if ("200".equals(jsonObject.get("code").toString())) {
                if (jsonObject.containsKey("data")) {
                    return JsonResult.ok(jsonObject.get("data"));
                } else {
                    return JsonResult.ok();
                }
            }
        }
        if (jsonObject.containsKey("msg")) {
            logger.info(jsonObject.get("msg").toString());
            result.setMessage(jsonObject.get("msg").toString());
            result.setCode(ResultCode.INTERNAL_SERVER_ERROR);
        }
        return result;
    }

    /*
     * get 请求
     * */
    public static JsonResult getRequest(String url, Map params) throws Exception {
        JsonResult result = new JsonResult();
        String returnData = HttpClientUtils.getJsonForParam(url, params);
        if (StringUtils.isEmpty(returnData)) {
            throw new RuntimeException("failed！");
        }
        logger.info("############## response results{}" + returnData);
        Map jsonObject = JSONObject.parseObject(returnData);
        if (jsonObject.containsKey("code")) {
            if ("200".equals(jsonObject.get("code").toString())) {
                return JsonResult.ok();
            }
        }
        if (jsonObject.containsKey("msg")) {
            logger.info(jsonObject.get("msg").toString());
            result.setMessage(jsonObject.get("msg").toString());
            result.setCode(ResultCode.INTERNAL_SERVER_ERROR);
        }
        return result;
    }
}
