package com.jz.dmp.modules.controller.DataIntegration;

import com.amazonaws.services.xray.model.Http;
import com.jz.common.annotation.SysOperationLogAnnotation;
import com.jz.common.constant.CommConstant;
import com.jz.common.constant.JsonResult;
import com.jz.common.constant.ResultCode;
import com.jz.common.page.BasePageBean;
import com.jz.common.page.PageInfoResponse;
import com.jz.dmp.modules.controller.DataIntegration.bean.*;
import com.jz.dmp.modules.service.DmpSyncingDatasourceTypeService;
import com.jz.dmp.modules.service.OfflineSynchService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;
import org.apache.commons.lang3.StringUtils;
import org.apache.http.HttpRequest;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.*;

import javax.servlet.http.HttpServletRequest;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

/**
 * @Description:离线同步
 * @ClassName: OfflineSynchController
 * @Author Bellamy
 * @Date 2020/12/20
 */
@RestController
@RequestMapping("/offlineSynch")
@Api(tags = "数据集成--离线同步")
public class OfflineSynchController {

    @Autowired
    private OfflineSynchService offlineSynchService;

    @Autowired
    private DmpSyncingDatasourceTypeService dmpSyncingDatasourceTypeService;

    /**
     * 离线同步任务列表分页查询
     *
     * @return
     * @author Bellamy
     */
    @ApiOperation(value = "任务列表分页查询", notes = "任务列表分页查询")
    @PostMapping(value = "/taskListPage")
    public PageInfoResponse<TaskListPageDto> getTaskListPage(@RequestBody @Validated TaskListPageReq taskListPageReq) {
        PageInfoResponse<TaskListPageDto> pageInfo = new PageInfoResponse<TaskListPageDto>();
        try {
            pageInfo = offlineSynchService.queryTaskListPage(taskListPageReq);
        } catch (Exception e) {
            pageInfo.setMessage("查询失败");
            pageInfo.setCode(ResultCode.INTERNAL_SERVER_ERROR);
            e.printStackTrace();
        }
        return pageInfo;
    }

    /**
     * 获取源数据库名称——下拉框
     *
     * @return
     * @author Bellamy
     */
    @ApiOperation(value = "获取源数据库名称-下拉框", notes = "获取源数据库名称")
    @GetMapping(value = "/sourceDbList")
    @ApiImplicitParams({@ApiImplicitParam(name = "projectId", value = "项目id", required = true)
            , @ApiImplicitParam(name = "datasourceTypeId", value = "数据源类型id")
            , @ApiImplicitParam(name = "type", value = "01:来源，02目标")
    })
    public JsonResult<List<SourceDbNameListDto>> getSourceDbList(@RequestParam Integer projectId, @RequestParam(required = false) String type, @RequestParam(required = false) String datasourceTypeId) throws Exception {
        JsonResult<List<SourceDbNameListDto>> jsonResult = offlineSynchService.querygSourceDbList(projectId, datasourceTypeId);
        return jsonResult;
    }

    /**
     * 获取数据源类型——下拉框
     *
     * @return
     * @author Bellamy
     * @since 2021-01-21
     */
    @ApiOperation(value = "获取数据源类型—下拉框", notes = "获取数据源类型—下拉框")
    @GetMapping(value = "/datasourceList")
    public JsonResult getDatasourceList() throws Exception {
        JsonResult list = dmpSyncingDatasourceTypeService.queryDatasourceList();
        return list;
    }

    /**
     * 根据源数据库id,获取源数据表——下拉框
     *
     * @return
     * @author Bellamy
     */
    @ApiOperation(value = "根据源数据库id,获取源数据表-下拉框", notes = "根据源数据库id,获取源数据表")
    @GetMapping(value = "/sourceTableList")
    @ApiImplicitParams({@ApiImplicitParam(name = "sourceDbId", value = "源数据库id", required = true)})
    public JsonResult getSourceTableList(@RequestParam Long sourceDbId, @RequestParam(value = "targetName", required = false) String targetName) throws Exception {
        JsonResult list = offlineSynchService.querygSourceTableList(sourceDbId, targetName);
        return list;
    }

    /**
     * 任务立即运行
     *
     * @return
     * @author Bellamy
     */
    @ApiOperation(value = "任务立即运行", notes = "任务立即运行")
    @GetMapping(value = "/taskRunNowByTaskId")
    @ApiImplicitParam(name = "taskId", value = "任务id")
    @SysOperationLogAnnotation(actionType = CommConstant.OPT_TYPE_RUN, descrption = "任务立即运行", optModular = CommConstant.MODULAR_DATAINTEGRATION_OFFLINE, isProjOpt = true)
    public JsonResult getTaskRunNowByTaskId(@RequestParam(value = "taskId") String taskId) throws Exception {
        if (StringUtils.isEmpty(taskId)) {
            return new JsonResult(ResultCode.PARAMS_ERROR);
        }
        JsonResult list =  new JsonResult();
        try {
            list = offlineSynchService.taskRunNowByTaskId(taskId);
        } catch (Exception e) {
            list.setMessage(e.getMessage());
            list.setCode(ResultCode.INTERNAL_SERVER_ERROR);
            e.printStackTrace();
        }
        return list;
    }

    /**
     * 任务停止运行
     *
     * @return
     * @author Bellamy
     * @since 2021-01-07
     */
    @ApiOperation(value = "停止运行", notes = "停止运行")
    @GetMapping(value = "/stopSyncingTask")
    @ApiImplicitParam(name = "taskId", value = "任务id")
    @SysOperationLogAnnotation(actionType = CommConstant.OPT_TYPE_STOP, descrption = "任务停止运行", optModular = CommConstant.MODULAR_DATAINTEGRATION_OFFLINE, isProjOpt = true)
    public JsonResult stopTaskRunNowByTaskId(@RequestParam(value = "taskId") String taskId) throws Exception {
        if (StringUtils.isEmpty(taskId)) {
            return new JsonResult(ResultCode.PARAMS_ERROR);
        }
        JsonResult list = new JsonResult();
        try {
            list = offlineSynchService.stopSyncingTaskByTaskId(taskId);
        } catch (Exception e) {
            list.setMessage(e.getMessage());
            list.setCode(ResultCode.INTERNAL_SERVER_ERROR);
            e.printStackTrace();
        }
        return list;
    }

    /**
     * 根据taskId删除离线任务和任务树
     *
     * @return
     * @author Bellamy
     * @Date 2021/02/03
     */
    @ApiOperation(value = "删除任务", notes = "删除任务")
    @GetMapping(value = "/delTaskByTaskId")
    @ApiImplicitParam(name = "taskId", value = "任务id")
    @SysOperationLogAnnotation(actionType = CommConstant.OPT_TYPE_DELETE, descrption = "删除任务", optModular = CommConstant.MODULAR_DATAINTEGRATION_OFFLINE, isProjOpt = true)
    public JsonResult delTaskByTaskId(@RequestParam(value = "taskId") String taskId) throws Exception {
        if (StringUtils.isEmpty(taskId)) {
            return new JsonResult(ResultCode.PARAMS_ERROR);
        }
        JsonResult list = offlineSynchService.delTaskByTaskId(taskId);
        return list;
    }

    /**
     * 状态查看列表分页查询
     *
     * @return
     * @author Bellamy
     */
    @ApiOperation(value = "状态查看", notes = "状态查看列表分页查询")
    @PostMapping(value = "/checkTaskStatus")
    public JsonResult<List<CheckTaskStatusPageDto>> getCheckTaskStatusListPage(@RequestBody @Validated CheckTaskStatusPageReq checkTaskStatusPageReq) throws Exception {
        JsonResult<List<CheckTaskStatusPageDto>> list = offlineSynchService.queryCheckTaskStatusListPage(checkTaskStatusPageReq);
        return list;
    }

    /**
     * 校验状态详情--查看 规则执行结果
     *
     * @return
     * @author Bellamy
     */
    @ApiOperation(value = "校验状态详情--查看", notes = "校验状态详情--查看")
    @PostMapping(value = "/checkJyStatusInfo")
    public PageInfoResponse<CheckJyRlueStatusDto> getCheckStatusInfo(@RequestBody @Validated CheckJyRlueStatusReq checkJyRlueStatusReq) throws Exception {
        PageInfoResponse<CheckJyRlueStatusDto> pageInfo = new PageInfoResponse<CheckJyRlueStatusDto>();
        try {
            pageInfo = offlineSynchService.selectCheckJyStatusInfo(checkJyRlueStatusReq);
        } catch (Exception e) {
            pageInfo.setMessage("查询失败");
            pageInfo.setCode(ResultCode.INTERNAL_SERVER_ERROR);
            e.printStackTrace();
        }
        return pageInfo;
    }

    /**
     * 获取数据源表字段
     *
     * @return
     * @author Bellamy
     */
    @ApiOperation(value = "获取数据源表字段", notes = "获取数据源表字段")
    @PostMapping(value = "/getSoureAndTargetColumns")
    public JsonResult getSoureAndTargetColumns(@RequestBody @Validated Map<String, List<SynchTableColumnsReq>> req) throws Exception {
        JsonResult jsonResult = new JsonResult();
        try {
            jsonResult = offlineSynchService.querySoureTableColumns(req);
        } catch (Exception e) {
            jsonResult.setMessage(e.getMessage());
            jsonResult.setCode(ResultCode.INTERNAL_SERVER_ERROR);
            e.printStackTrace();
        }
        return jsonResult;
    }

    /**
     * sync-获取数据源表字段
     *
     * @return
     * @author Bellamy
     */
    @ApiOperation(value = "sync-获取数据源表字段", notes = "sync-获取数据源表字段")
    @PostMapping(value = "/getSyncColumns")
    public JsonResult getSyncSoureAndTargetColumns(@RequestBody @Validated Map<String, List<SynchTableColumnsReq>> req) throws Exception {
        JsonResult jsonResult = new JsonResult();
        try {
            jsonResult = offlineSynchService.getSyncSoureAndTargetColumns(req);
        } catch (Exception e) {
            jsonResult.setMessage(e.getMessage());
            jsonResult.setCode(ResultCode.INTERNAL_SERVER_ERROR);
            e.printStackTrace();
        }
        return jsonResult;
    }

    /**
     * 校验规则
     *
     * @return
     * @author Bellamy
     */
    @ApiOperation(value = "校验规则", notes = "校验规则")
    @PostMapping(value = "/findListJyRule")
    public PageInfoResponse<DvRuleTDto> findListJyRule(@RequestBody BasePageBean basePageBean, HttpServletRequest httpRequest) throws Exception {
        PageInfoResponse<DvRuleTDto> pageInfo = new PageInfoResponse<DvRuleTDto>();
        try {
            pageInfo = offlineSynchService.queryJyRuleListPage(basePageBean, httpRequest);
        } catch (Exception e) {
            pageInfo.setMessage("查询失败");
            pageInfo.setCode(ResultCode.INTERNAL_SERVER_ERROR);
            e.printStackTrace();
        }
        return pageInfo;
    }

    /**
     * 保存/编辑离线任务数据
     *
     * @return
     * @author Bellamy
     */
    @ApiOperation(value = "保存/编辑离线任务数据", notes = "保存/编辑离线任务数据")
    @PostMapping(value = "/addSyncTask")
    @SysOperationLogAnnotation(actionType = CommConstant.OPT_TYPE_EDIT, descrption = "保存/编辑离线任务数据", optModular = CommConstant.MODULAR_DATAINTEGRATION_OFFLINE, isProjOpt = true)
    public JsonResult addSyncTask(@RequestBody @Validated SyncDmpTaskAddReq syncDmpTaskAddReq) throws Exception {
        JsonResult list = new JsonResult();
        try {
            list = offlineSynchService.addSyncTask(syncDmpTaskAddReq);
        } catch (Exception e) {
            list.setCode(ResultCode.INTERNAL_SERVER_ERROR);
            list.setMessage(e.getMessage());
            e.printStackTrace();
        }
        return list;
    }

    /**
     * 离线任务详情--编辑回显
     *
     * @return
     * @author Bellamy
     */
    @ApiOperation(value = "离线任务详情--编辑回显", notes = "离线任务详情--编辑回显")
    @GetMapping(value = "/getSyncTaskInfoById")
    @ApiImplicitParam(name = "id",value = "离线任务id",required = true)
    public JsonResult getSyncTaskInfoById(@RequestParam String id) throws Exception {
        if(StringUtils.isEmpty(id)){
            return JsonResult.error(ResultCode.PARAMS_ERROR,"id不能为空");
        }
        JsonResult list = new JsonResult();
        try {
            list = offlineSynchService.querySyncTaskInfoById(id);
        } catch (Exception e) {
            list.setCode(ResultCode.INTERNAL_SERVER_ERROR);
            list.setMessage("failed!");
            e.printStackTrace();
        }
        return list;
    }

    /**
     * 编辑离线任务数据
     *
     * @return
     * @author Bellamy
     */
    @ApiOperation(value = "编辑离线任务数据", notes = "编辑离线任务数据")
    @PostMapping(value = "/updateSyncTask")
    @SysOperationLogAnnotation(actionType = CommConstant.OPT_TYPE_EDIT, descrption = "编辑离线任务数据", optModular = CommConstant.MODULAR_DATAINTEGRATION_OFFLINE, isProjOpt = true)
    public JsonResult updateSyncTask(@RequestBody @Validated SyncDmpTaskAddReq syncDmpTaskAddReq) throws Exception {
        JsonResult list = offlineSynchService.updateSyncTask(syncDmpTaskAddReq);
        return list;
    }

    /**
     * 新增同步任务
     *
     * @return
     * @author Bellamy
     * @since 2021-01-26
     */
    @ApiOperation(value = "新增同步任务", notes = "新增同步任务")
    @PostMapping(value = "/newSynchTask")
    @SysOperationLogAnnotation(actionType = CommConstant.OPT_TYPE_ADD, descrption = "新增同步任务", optModular = CommConstant.MODULAR_DATAINTEGRATION_OFFLINE, isProjOpt = true)
    public JsonResult addNewSynchTask(@RequestBody @Validated NewSynchTaskReq newSynchTaskReq) throws Exception {
        if (StringUtils.isEmpty(newSynchTaskReq.getProjectId())) {
            return JsonResult.error(ResultCode.PARAMS_ERROR, "项目ID不能为空");
        }
        if (StringUtils.isEmpty(newSynchTaskReq.getTreeName())) {
            return JsonResult.error(ResultCode.PARAMS_ERROR, "任务名称不能为空");
        }
        if (StringUtils.isEmpty(newSynchTaskReq.getType())) {
            return JsonResult.error(ResultCode.PARAMS_ERROR, "任务类型不能为空");
        }
        if (StringUtils.isEmpty(newSynchTaskReq.getProjectId())) {
            return JsonResult.error(ResultCode.PARAMS_ERROR, "目标文件夹不能为空");
        }
        JsonResult list = offlineSynchService.addNewSynchTask(newSynchTaskReq);
        return list;
    }

    /**
     * 数据预览
     *
     * @return
     * @author Bellamy
     * @since 2021-02-19
     */
    @ApiOperation(value = "数据预览", notes = "数据预览")
    @PostMapping(value = "/dataPreview")
    public JsonResult getDataPreview(@RequestBody @Validated OfflineDataPreview req) throws Exception {
        JsonResult jsonResult = new JsonResult();
        try {
            jsonResult = offlineSynchService.getDataPreview(req);
        } catch (Exception e) {
            jsonResult.setMessage(e.getMessage());
            jsonResult.setCode(ResultCode.INTERNAL_SERVER_ERROR);
            e.printStackTrace();
        }
        return jsonResult;
    }

}
