package com.jz.dmp.modules.controller;

import java.util.Arrays;
import java.util.List;
import java.util.stream.Collectors;
import javax.servlet.http.HttpServletRequest;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.bind.annotation.RestController;
import com.jz.common.annotation.MethodCallLogPrint;
import com.jz.common.bean.BaseBeanResponse;
import com.jz.common.bean.BaseResponse;
import com.jz.common.bean.PageInfoResponse;
import com.jz.common.constant.StatuConstant;
import com.jz.dmp.modules.controller.bean.DmpOptLogBatch;
import com.jz.dmp.modules.controller.bean.DmpOptLogDto;
import com.jz.dmp.modules.controller.bean.DmpOptLogRequest;
import com.jz.dmp.modules.model.DmpOptLog;
import com.jz.dmp.modules.service.DmpOptLogService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;

/**
 * 操作日志表Controller
 * @author ybz
 *
 */
@RestController
@RequestMapping("/dmp/opt/log")
@Api(tags = "操作日志表")
public class DmpOptLogController {
	
	@Autowired
	private DmpOptLogService dmpOptLogService;
	
	/**列表查询操作日志表
	 * @param dmpOptLogRequest
	 * @return
	 */
	@MethodCallLogPrint
	@RequestMapping(method = RequestMethod.POST, value = "/findListWithPage")
	@ApiOperation(value = "分頁列表查询操作日志表", notes = "分頁列表查询操作日志表")
	public PageInfoResponse<DmpOptLogDto> findListWithPage(@RequestBody DmpOptLogRequest dmpOptLogRequest, HttpServletRequest httpRequest){
		PageInfoResponse<DmpOptLogDto> pageInfo = new PageInfoResponse<DmpOptLogDto>();
		try {
			pageInfo = dmpOptLogService.findListWithPage(dmpOptLogRequest, httpRequest);
		} catch (Exception e) {
			pageInfo.setMessage("查询失败");
			pageInfo.setCode(StatuConstant.FAILURE_CODE);
			e.printStackTrace();
		}
		
		return pageInfo;
	}
	
	/**列表查询操作日志表
	 * @param dmpOptLogRequest
	 * @return
	 */
	//@MethodCallLogPrint
	//@RequestMapping(method = RequestMethod.POST, value = "/findList")
	//@ApiOperation(value = "列表查询操作日志表", notes = "列表查询操作日志表")
	public BaseBeanResponse<DmpOptLogDto> findList(@RequestBody DmpOptLogRequest dmpOptLogRequest, HttpServletRequest httpRequest){
		BaseBeanResponse<DmpOptLogDto> baseBeanResponse = new BaseBeanResponse<DmpOptLogDto>();
		try {
			baseBeanResponse = dmpOptLogService.findList(dmpOptLogRequest, httpRequest);
		} catch (Exception e) {
			baseBeanResponse.setMessage("查询失败");
			baseBeanResponse.setCode(StatuConstant.FAILURE_CODE);
			e.printStackTrace();
		}
		
		return baseBeanResponse;
	}
	
	
	/**主键查询操作日志表
	 * @param dmpOptLogRequest
	 * @return
	 */
	//@MethodCallLogPrint
	//@RequestMapping(method = RequestMethod.GET, value = "/view")
	//@ApiOperation(value = "主键查询操作日志表", notes = "主键查询操作日志表")
	//@ApiImplicitParam(name = "optId", value = "操作日志表主键")
	public BaseBeanResponse<DmpOptLogDto> view(@RequestParam(name = "optId", required = true ) Integer optId, HttpServletRequest httpRequest){
		BaseBeanResponse<DmpOptLogDto> baseBeanResponse = new BaseBeanResponse<DmpOptLogDto>();
		try {
			baseBeanResponse = dmpOptLogService.findById(optId, httpRequest);
		} catch (Exception e) {
			baseBeanResponse.setMessage("请求失败");
			baseBeanResponse.setCode(StatuConstant.FAILURE_CODE);
			e.printStackTrace();
		}
		
		return baseBeanResponse;
	}
	
	/**删除操作日志表
	 * @param optId
	 * @return
	 */
	//@MethodCallLogPrint
	//@RequestMapping(method = RequestMethod.GET, value = "/deleteById")
	//@ApiOperation(value = "删除操作日志表", notes = "删除操作日志表")
	//@ApiImplicitParam(name = "optId", value = "操作日志表主键")
	public BaseResponse deleteById(@RequestParam(name = "optId", required = true ) Integer optId, HttpServletRequest httpRequest){
		BaseResponse baseResponse = new BaseResponse();
		try {
			baseResponse = dmpOptLogService.deleteById(optId, httpRequest);
		} catch (Exception e) {
			baseResponse.setMessage("删除失败");
			baseResponse.setCode(StatuConstant.FAILURE_CODE);
			e.printStackTrace();
		}
		
		return baseResponse;
	}
	
	/**软删除操作日志表
	 * @param optId
	 * @return
	 */
	//@MethodCallLogPrint
	//@RequestMapping(method = RequestMethod.GET, value = "/softDeleteById")
	//@ApiOperation(value = "软删除操作日志表", notes = "软删除操作日志表")
	//@ApiImplicitParam(name = "optId", value = "操作日志表主键")
	public BaseResponse softDeleteById(@RequestParam(name = "optId", required = true ) Integer optId, HttpServletRequest httpRequest){
		BaseResponse baseResponse = new BaseResponse();
		try {
			baseResponse = dmpOptLogService.softDeleteById(optId, httpRequest);
		} catch (Exception e) {
			baseResponse.setMessage("软删除失败");
			baseResponse.setCode(StatuConstant.FAILURE_CODE);
			e.printStackTrace();
		}
		
		return baseResponse;
	}
	
	/**删除操作日志表
	 * @param optId
	 * @return
	 */
	//@MethodCallLogPrint
	//@RequestMapping(method = RequestMethod.GET, value = "/delete")
	//@ApiOperation(value = "删除操作日志表", notes = "删除操作日志表")
	//@ApiImplicitParam(name = "ids", value = "操作日志表主键集（逗号隔开）")
	public BaseResponse delete(@RequestParam(name = "ids", required = true ) String ids, HttpServletRequest httpRequest){
		BaseResponse baseResponse = new BaseResponse();
		try {
			//参数封装
			String[] idStrs = ids.split(",");
			List<Integer> idList = Arrays.asList(idStrs).stream().map(x->{
				return Integer.parseInt(x);
			}).collect(Collectors.toList());
			
			baseResponse = dmpOptLogService.deleteByIds(idList, httpRequest);
		} catch (Exception e) {
			baseResponse.setMessage("删除失败");
			baseResponse.setCode(StatuConstant.FAILURE_CODE);
			e.printStackTrace();
		}
		
		return baseResponse;
	}
	
	/**软删除操作日志表
	 * @param optId
	 * @return
	 */
	//@MethodCallLogPrint
	//@RequestMapping(method = RequestMethod.GET, value = "/softDelete")
	//@ApiOperation(value = "软删除操作日志表", notes = "软删除操作日志表")
	//@ApiImplicitParam(name = "ids", value = "操作日志表主键集（逗号隔开）")
	public BaseResponse softDelete(@RequestParam(name = "ids", required = true ) String ids, HttpServletRequest httpRequest){
		BaseResponse baseResponse = new BaseResponse();
		try {
			//参数封装
			String[] idStrs = ids.split(",");
			List<Integer> idList = Arrays.asList(idStrs).stream().map(x->{
				return Integer.parseInt(x);
			}).collect(Collectors.toList());
			
			baseResponse = dmpOptLogService.softDeleteByIds(idList, httpRequest);
		} catch (Exception e) {
			baseResponse.setMessage("软删除失败");
			baseResponse.setCode(StatuConstant.FAILURE_CODE);
			e.printStackTrace();
		}
		
		return baseResponse;
	}
	
	/**条件删除操作日志表
	 * @param optId
	 * @return
	 */
	//@MethodCallLogPrint
	//@RequestMapping(method = RequestMethod.POST, value = "/deleteByPojo")
	//@ApiOperation(value = "条件删除操作日志表", notes = "条件删除操作日志表")
	public BaseResponse deleteByPojo(@RequestBody DmpOptLogRequest dmpOptLogRequest, HttpServletRequest httpRequest){
		BaseResponse baseResponse = new BaseResponse();
		try {
			baseResponse = dmpOptLogService.delete(dmpOptLogRequest, httpRequest);
		} catch (Exception e) {
			baseResponse.setMessage("删除失败");
			baseResponse.setCode(StatuConstant.FAILURE_CODE);
			e.printStackTrace();
		}
		
		return baseResponse;
	}
	
	/**条件软删除操作日志表
	 * @param optId
	 * @return
	 */
	//@MethodCallLogPrint
	//@RequestMapping(method = RequestMethod.POST, value = "/softDeleteByPojo")
	//@ApiOperation(value = "条件软删除操作日志表", notes = "条件软删除操作日志表")
	public BaseResponse softDeleteByPojo(@RequestBody DmpOptLogRequest dmpOptLogRequest, HttpServletRequest httpRequest){
		BaseResponse baseResponse = new BaseResponse();
		try {
			baseResponse = dmpOptLogService.softDelete(dmpOptLogRequest, httpRequest);
		} catch (Exception e) {
			baseResponse.setMessage("软删除失败");
			baseResponse.setCode(StatuConstant.FAILURE_CODE);
			e.printStackTrace();
		}
		
		return baseResponse;
	}
	
	/**新增操作日志表
	 * @param dmpOptLogRequest
	 * @return
	 */
	//@MethodCallLogPrint
	//@RequestMapping(method = RequestMethod.POST, value = "/add")
	//@ApiOperation(value = "新增操作日志表", notes = "新增操作日志表")
	public BaseBeanResponse<DmpOptLog> add(@RequestBody DmpOptLog dmpOptLog, HttpServletRequest httpRequest){
		BaseBeanResponse<DmpOptLog> baseBeanResponse = new BaseBeanResponse<DmpOptLog>();
		try {
			baseBeanResponse = dmpOptLogService.add(dmpOptLog, httpRequest);
		} catch (Exception e) {
			baseBeanResponse.setMessage("新增失败");
			baseBeanResponse.setCode(StatuConstant.FAILURE_CODE);
			e.printStackTrace();
		}
		
		return baseBeanResponse;
	}
	
	/**批量新增操作日志表
	 * @param dmpOptLogRequest
	 * @return
	 */
	//@MethodCallLogPrint
	//@RequestMapping(method = RequestMethod.POST, value = "/addBatch")
	//@ApiOperation(value = "批量新增操作日志表", notes = "批量新增操作日志表")
	public BaseBeanResponse<DmpOptLogBatch> addBatch(@RequestBody DmpOptLogBatch dmpOptLogBatch, HttpServletRequest httpRequest){
		BaseBeanResponse<DmpOptLogBatch> baseBeanResponse = new BaseBeanResponse<DmpOptLogBatch>();
		try {
			baseBeanResponse = dmpOptLogService.addBatch(dmpOptLogBatch, httpRequest);
		} catch (Exception e) {
			baseBeanResponse.setMessage("批量新增失败");
			baseBeanResponse.setCode(StatuConstant.FAILURE_CODE);
			e.printStackTrace();
		}
		
		return baseBeanResponse;
	}
	
	/**修改操作日志表
	 * @param dmpOptLogRequest
	 * @return
	 */
	//@MethodCallLogPrint
	//@RequestMapping(method = RequestMethod.POST, value = "/edit")
	//@ApiOperation(value = "修改操作日志表", notes = "修改操作日志表")
	public BaseBeanResponse<DmpOptLog> edit(@RequestBody DmpOptLog dmpOptLog, HttpServletRequest httpRequest){
		BaseBeanResponse<DmpOptLog> baseBeanResponse = new BaseBeanResponse<DmpOptLog>();
		try {
			baseBeanResponse = dmpOptLogService.edit(dmpOptLog, httpRequest);
		} catch (Exception e) {
			baseBeanResponse.setMessage("修改失败");
			baseBeanResponse.setCode(StatuConstant.FAILURE_CODE);
			e.printStackTrace();
		}
		
		return baseBeanResponse;
	}
	
	/**新增或修改操作日志表
	 * @param dmpOptLogRequest
	 * @return
	 */
	//@MethodCallLogPrint
	//@RequestMapping(method = RequestMethod.POST, value = "/addOrEdit")
	//@ApiOperation(value = "新增或修改操作日志表", notes = "新增或修改操作日志表")
	public BaseBeanResponse<DmpOptLog> addOrEdit(@RequestBody DmpOptLog dmpOptLog, HttpServletRequest httpRequest){
		BaseBeanResponse<DmpOptLog> baseBeanResponse = new BaseBeanResponse<DmpOptLog>();
		try {
			baseBeanResponse = dmpOptLogService.addOrEdit(dmpOptLog, httpRequest);
		} catch (Exception e) {
			baseBeanResponse.setMessage("新增或修改失败");
			baseBeanResponse.setCode(StatuConstant.FAILURE_CODE);
			e.printStackTrace();
		}
		
		return baseBeanResponse;
	}
	
}
